pub struct PublicKey { /* private fields */ }Expand description
PublicKey used to store the ECDHPublicKey object or a wrapper of it
This object give a helper methods to convert, encode and decode the data, which is a public key
Implementations