PrivKey

Struct PrivKey 

pub struct PrivKey { /* private fields */ }
PrivKey is a private key generated from SigningKey

This object also able to serialize and encode the private key into PEM format Once this object encoded into PEM, we also able to encrypt the data and generate KeySecure object from it through trait ToKeySecure.

Implementations

Source

impl PrivKey

pub fn new(key: SigningKey) -> Self

pub fn serialize(&self) -> PrivateKeyBytes

pub fn to_pem(&self) -> Result<String, EddsaError>