PubKey

Struct PubKey 

pub struct PubKey { /* private fields */ }
PubKey is an object that will serialize and encode the VerifyingKey

This key should be able used to validate the signature that made by it’s private key

Implementations

Source

impl PubKey

pub fn new(key: VerifyingKey) -> Self

pub fn serialize(&self) -> PublicKeyBytes

pub fn to_hex(&self) -> ByteHex

pub fn from_hex(val: ByteHex) -> Result<Self, EddsaError>

pub fn verify( &self, message: &[u8], signature_hex: ByteHex, ) -> Result<bool, EddsaError>