VectorValue

Trait VectorValue 

pub trait VectorValue<T> {
    // Required method
    fn vec(&self) -> Vec<T>;
}
VectorValue is a trait used to get main vector value. It has a generic parameter used to indicate a real data types will used inside the vector

Required Methods

fn vec(&self) -> Vec<T>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors